@extends('layouts.app')

@section("title", "User Settings")

@section('content')

    <div class="page-header">
        <nav aria-label="breadcrumb" class="d-flex align-items-start">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a href="{{ url('/') }}">Dashboard</a>
                </li>
                <li class="breadcrumb-item active" aria-current="page">Settings</li>
            </ol>
        </nav>
    </div>

    <div class="row">
        <div class="col-md-12">

            <div class="row">
                <div class="col-lg-3 col-md-12 mb-3">
                    <div class="nav flex-lg-column flex-sm-row nav-pills" id="#tabMenu" role="tablist" aria-orientation="vertical">
                        <a class="nav-link {{$active_tab == 'account' ? 'active' : ""}}" id="account-tab" data-toggle="pill" href="#account" role="tab" aria-controls="account" aria-selected="true">Account</a>
                        <a class="nav-link {{$active_tab == 'security' ? 'active' : ""}}" id="security-tab" data-toggle="pill" href="#security" role="tab" aria-controls="security" aria-selected="false">Security</a>
                        @if(auth()->user()->hasPermission('manage_file_types'))
                        <a class="nav-link {{$active_tab == 'file-types' ? 'active' : ""}}" id="file-types-tab" data-toggle="pill" href="#file-types" role="tab" aria-controls="file-types" aria-selected="false">File validation</a>
                        @endif
                    </div>
                </div>
                <div class="col-lg-9 col-md-12">
                    <div class="tab-content" id="v-pills-tabContent">
                        <div class="tab-pane {{$active_tab == 'account' ? 'active' : ""}}" id="account" role="tabpanel" aria-labelledby="account-tab">
                            <div class="card">
                                <div class="card-body">
                                    <h6 class="card-title">Account</h6>
                                    <form action="{{ route("dashboard.users.editUserData", ["id" =>$user->id]) }}" method="post" accept-charset="utf-8" enctype='multipart/form-data' class="needs-validation" novalidate>
                                        @method("patch")
                                        @csrf
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Name</label>
                                                    <input type="text" name="name" value="{{ $user->name }}" minlength="2" maxlength="30" class="form-control" placeholder="Name" required>
                                                    <div class="invalid-feedback">
                                                        Please enter only letters and spaces with length between [2, 30]
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Surname</label>
                                                    <input type="text" name="surname" value="{{$user->surname}}" class="form-control" placeholder="Surname" required>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label class="form-label">Mobile Number</label>
                                                    <input type="text" name="phone_number" value="{{ $user->phone_number }}" class="form-control" placeholder="Phone number" autocomplete="off" required>
                                                </div>
                                            </div>
                                            <div class="col-md-5">
                                                <div class="form-group">
                                                    <label>Avatar</label>
                                                    <input type="file" name="avatar" value="{{ $user->avatar }}" class="form-control" accept="image/*">
                                                </div>
                                            </div>
                                        <div class="col-md-1">
                                            <div class="form-group">
                                                <label></label>
                                                <figure class="avatar avatar-sm mr-2">
                                                    @if(auth()->user()->avatar==NULL)
                                                        <img src="{{ url('assets/media/images/user.png') }}" class="rounded-circle" alt="avatar">
                                                    @else
                                                        <img src="{{url('uploads/users/' . auth()->user()->avatar)}}" class="rounded-circle" alt="avatar">
                                                    @endif
                                                </figure>

                                            </div>
                                        </div>
                                        </div>
                                        <input type="submit" value="Save changes" class="submitBtn btn btn-primary pull-right m-10">
                                    </form>
                                </div>
                            </div>
                        </div>
                        <div class="tab-pane {{$active_tab == 'security' ? 'active' : ""}}" id="security" role="tabpanel" aria-labelledby="security-tab">
                            <div class="card">
                                <div class="card-body">
                                    <form class="actionForm" action="{{ route("dashboard.settings.password") }}"
                                          method="post" accept-charset="UTF-8">

                                        @method("patch")
                                        @csrf

                                        <fieldset class="form-fieldset">

                                            <h4 class="font-weight-normal border-bottom pb-2">Password</h4>

                                            <h6 class="font-weight-normal text-muted">After changing your
                                                password you will be logged out automatically.</h6>

                                            <div class="row">

                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label class="form-label">Current Password <span
                                                                class="form-required">*</span></label>
                                                        <input type="password" class="form-control"
                                                               name="current_password" autocomplete="off"
                                                               required>
                                                    </div>
                                                </div>

                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label class="form-label">New Password <span
                                                                class="form-required">*</span></label>
                                                        <input type="password" class="form-control"
                                                               name="password" autocomplete="off" required>
                                                    </div>
                                                </div>

                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label class="form-label">Repeat New Password <span
                                                                class="form-required">*</span></label>
                                                        <input type="password" class="form-control"
                                                               name="password_confirmation" autocomplete="off"
                                                               required>
                                                    </div>
                                                </div>

                                                <div class="col-md-12">
                                                    <div class="form-group mb-0 float-right">
                                                        <input type="submit" value="Submit"
                                                               class="submitBtn btn btn-primary">
                                                    </div>
                                                </div>

                                            </div>

                                        </fieldset>

                                    </form>
                                </div>
                            </div>


                            <div class="card">
                                <div class="card-body">

                                            <h4 class="font-weight-normal border-bottom pb-2">Username</h4>

                                            <h6 class="font-weight-normal text-muted">After changing your
                                                username you will be logged out automatically.</h6>

                                            <div class="row">

                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label class="form-label">Username</label>
                                                        <input type="text" id="username"
                                                               value="{{ old("username", $user->username) }}"
                                                               name="username" class="form-control">
                                                    </div>
                                                </div>

                                                <div class="col-md-12">
                                                    <div class="form-group mb-0 float-right">
                                                        <a href="javascript:void(0)" class="submitBtn btn btn-primary text-white" data-toggle="modal" id="submitUserName" data-target="#confirmUsernameModal">Submit</a>
                                                    </div>
                                                </div>

                                            </div>

                                </div>
                    </div>

                            <div class="card">
                                <div class="card-body">

                                            <h4 class="font-weight-normal border-bottom pb-2">E-mail</h4>

                                            <h6 class="font-weight-normal text-muted">This is where lost
                                                password requests will be sent. After changing your e-mail you
                                                will be logged out automatically.</h6>

                                            <div class="row">

                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label class="form-label">E-mail</label>
                                                        <input type="email"
                                                               value="{{ old("email", $user->email) }}"
                                                               name="email" id="email" class="form-control">
                                                    </div>
                                                </div>

                                                <div class="col-md-12">
                                                    <div class="form-group mb-0 float-right">
                                                        <a href="javascript:void(0)" class="submitBtn btn btn-primary text-white" data-toggle="modal" id="submitEmail" data-target="#confirmEmailModal">Submit</a>
                                                    </div>
                                                </div>

                                            </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab-pane {{$active_tab == 'file-types' ? 'active' : ""}}" id="file-types" role="tabpanel" aria-labelledby="file-types-tab">
                            @if(auth()->user()->hasPermission('manage_file_types'))
                            <div class="card">
                                    <div class="card-body">
                                        <h6 class="card-title">File validation</h6>
                                        <form action="{{ route("dashboard.settings.file-types") }}" method="post" accept-charset="utf-8" enctype='multipart/form-data'>
                                            @method("patch")
                                            @csrf
                                            <div class="row">
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label>Mimes</label>
                                                        <input type="text" name="mimes" value="{{ $fileType->mimes }}" class="form-control" placeholder="Mimes" required>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label class="form-label">Max file size (in KB)</label>
                                                        <input type="number" name="max_size" value="{{  $fileType->max_size }}" class="form-control" placeholder="Max file size" autocomplete="off" required>
                                                        <p class="text-danger p-2">Note: 1 MB = 1024 KB</p>
                                                    </div>
                                                </div>
                                            </div>
                                            <input type="submit" value="Save changes" class="submitBtn btn btn-primary pull-right m-10">
                                        </form>
                                    </div>
                                </div>
                        @endif
                        </div>
                    </div>
                </div>
            </div>

        </div>
    </div>

    <div class="modal fade" id="confirmUsernameModal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exampleModalCenterTitle">Update confirmation</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <i class="ti-close"></i>
                    </button>
                </div>
                <div class="modal-body">
                    <form action="{{ route("dashboard.settings.username") }}" method="POST">

                        @method('patch')
                        @csrf

                        <p>Are you sure you want to update your username to <span id="user_name" class="font-weight-bold"></span>?</p>
                        <input type="hidden" id="user_name_input" value="" name="username">
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-dismiss="modal">Close
                            </button>
                            <button type="submit" class="btn btn-primary">Save changes</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="confirmEmailModal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exampleModalCenterTitle">Update confirmation</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <i class="ti-close"></i>
                    </button>
                </div>
                <div class="modal-body">
                    <form action="{{ route("dashboard.settings.email") }}" method="POST">

                        @method('patch')
                        @csrf

                        <p>Are you sure you want to update your email to <span id="user_email" class="font-weight-bold"></span>?</p>
                        <input type="hidden" id="user_email_input" value="" name="email">
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-dismiss="modal">Close
                            </button>
                            <button type="submit" class="btn btn-primary">Save changes</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

@endsection

@section('script')

    <script>
        $("#submitUserName").click(function () {
            var name = $("#username").val();
            $("#user_name").html(name);
            $("#user_name_input").val(name);
        });
    </script>

    <script>
        $("#submitEmail").click(function () {
            var email = $("#email").val();
            $("#user_email").html(email);
            $("#user_email_input").val(email);
        });
    </script>
@endsection
